==> vacuum-1.1.0.tar.xz: vacuum-1.1.0/src/translations/de/datastreamsmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>DataStreamsManger</name>
    <message>
        <source>Data Streams Manager</source>
        <translation>Datenstreams Manager</translation>
    </message>
    <message>
        <source>None of the available streams are acceptable</source>
        <translation>Keiner der verfügbaren Streams sind akzeptierbar</translation>
    </message>
    <message>
        <source>The profile is not understood or invalid</source>
        <translation>Das Profil wurde nicht verstanden oder ist ungültig</translation>
    </message>
    <message>
        <source>Invalid profile settings</source>
        <translation>Ungültige Profileinstellungen</translation>
    </message>
    <message>
        <source>Data Streams Initiation</source>
        <translation>Datenstrom Initiation</translation>
    </message>
    <message>
        <source>Stream with same ID already exists</source>
        <translation>Stream mit der selben ID existiert bereits</translation>
    </message>
    <message>
        <source>Data Streams</source>
        <translation>Daten Streams</translation>
    </message>
    <message>
        <source>&lt;Default Profile&gt;</source>
        <translation>&lt;Standard Profil&gt;</translation>
    </message>
    <message>
        <source>Allows to initiate a custom stream of data between two XMPP entities</source>
        <translation>Erlaubt das Initiieren von benutzerdefinierten Datenstreams zwischen zwei XMPP Entitäten</translation>
    </message>
    <message>
        <source>Supports the initiating of the custom stream of data between two XMPP entities</source>
        <translation>Unterstützt die Initiierung von eigenen Datenstreams zwischen zwei XMPP Entitäten</translation>
    </message>
    <message>
        <source>Invalid stream initiation response</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>DataStreamsOptions</name>
    <message>
        <source>Add Profile</source>
        <translation>Profil hinzufügen</translation>
    </message>
    <message>
        <source>Enter profile name:</source>
        <translation>Profilnamen eingeben:</translation>
    </message>
    <message>
        <source>Delete Profile</source>
        <translation>Profil löschen</translation>
    </message>
    <message>
        <source>Do you really want to delete a current data streams profile?</source>
        <translation>Wollen Sie wirklich ein aktuelles Datenstream Profil löschen?</translation>
    </message>
</context>
<context>
    <name>DataStreamsOptionsClass</name>
    <message>
        <source>Data Streams Profiles</source>
        <translation>Datenstreams Profile</translation>
    </message>
    <message>
        <source>Profile:</source>
        <translation>Profil:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>löschen</translation>
    </message>
</context>
</TS>

==> vacuum-1.2.4.tar.xz: vacuum-1.2.4/src/translations/de/datastreamsmanager.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="de" sourcelanguage="en">
<context>
    <name>DataStreamsManger</name>
    <message>
        <source>Data Streams Manager</source>
        <translation>Datenstrommanager</translation>
    </message>
    <message>
        <source>None of the available streams are acceptable</source>
        <translation>Keiner der verfügbaren Datenströme ist nutzbar</translation>
    </message>
    <message>
        <source>The profile is not understood or invalid</source>
        <translation>Das Profil wurde nicht verstanden oder ist ungültig</translation>
    </message>
    <message>
        <source>Invalid profile settings</source>
        <translation>Ungültige Profileinstellungen</translation>
    </message>
    <message>
        <source>Data Streams Initiation</source>
        <translation>Datenstrom Initiation</translation>
    </message>
    <message>
        <source>Stream with same ID already exists</source>
        <translation>Datenstrom mit der selben ID existiert bereits</translation>
    </message>
    <message>
        <source>Data Streams</source>
        <translation>Datenströme</translation>
    </message>
    <message>
        <source>&lt;Default Profile&gt;</source>
        <translation>&lt;Standard Profil&gt;</translation>
    </message>
    <message>
        <source>Allows to initiate a custom stream of data between two XMPP entities</source>
        <translation>Erlaubt den Aufbauen von benutzerdefinierten Datenströmen zwischen zwei XMPP Endpunkten</translation>
    </message>
    <message>
        <source>Supports the initiating of the custom stream of data between two XMPP entities</source>
        <translation>Unterstützt den Aufbau von eigenen Datenströmen zwischen zwei XMPP Endpunkten</translation>
    </message>
    <message>
        <source>Invalid stream initiation response</source>
        <translation>Ungültige Antwort auf Datenstromanfrage</translation>
    </message>
</context>
<context>
    <name>DataStreamsOptions</name>
    <message>
        <source>Add Profile</source>
        <translation>Profil hinzufügen</translation>
    </message>
    <message>
        <source>Enter profile name:</source>
        <translation>Profilnamen eingeben:</translation>
    </message>
    <message>
        <source>Delete Profile</source>
        <translation>Profil löschen</translation>
    </message>
    <message>
        <source>Do you really want to delete a current data streams profile?</source>
        <translation>Wollen Sie wirklich ein aktuelles Datenstrom Profil löschen?</translation>
    </message>
</context>
<context>
    <name>DataStreamsOptionsClass</name>
    <message>
        <source>Data Streams Profiles</source>
        <translation>Datenstromprofile</translation>
    </message>
    <message>
        <source>Profile:</source>
        <translation>Profil:</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Hinzufügen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
</context>
</TS>
